@@ -1,6 +1,48 @@
 #!/usr/bin/env python
 # coding: utf-8
 
+
+def  generate_augmento_simple(transform_featuress, los, magnitudes, nb_selecteds, leading_correlationss):
+    parameters = []
+    for transform_features in transform_featuress:
+        for lo in los:
+            for magnitude in magnitudes:
+                for nb_selected in nb_selecteds:
+                    for leading_correlations in leading_correlationss:
+                        parameters.append({
+                            'transform_features':transform_features,
+                            'lo':lo,
+                            'magnitude':magnitude,
+                            'nb_selected':nb_selected,
+                            'leading_correlations':leading_correlations
+                        })
+    return parameters
+
+def generate_simple_baseline(thresholds, signal_types, mixing_types):
+    parameters = []
+    for threshold in thresholds:
+        for signal_type in signal_types:
+            for mixing_type in mixing_types:
+                parameters.append({
+                    'threshold': threshold,
+                    'signal_type': signal_type,
+                    'mixing_type': mixing_type,
+                })
+    return parameters
+
+def generate_anova_like(signal_types, mixing_types):
+    parameters = []
+    for signal_type in signal_types:
+        for mixing_type in mixing_types:
+            parameters.append({
+                'signal_type': signal_type,
+                'mixing_type': mixing_type,
+            })
+    return parameters
+
+
+
+
 def generate_lead_lag(lookback_windows, lead_lags, contravariants, ):
     parameters = []
     for contravariant in contravariants:
